<?php
if(!class_exists('WP_List_Table')){
    require_once( ABSPATH . 'wp-admin/includes/class-wp-list-table.php' );
}

class WP_PayPalButtons_List_Table extends WP_List_Table {

	function __construct( $args = array() ) {
		parent::__construct( array(
            'singular'  => 'button',     	//singular name of the listed records
            'plural'    => 'buttons',    	//plural name of the listed records
            'ajax'      => true,       		//does this table support ajax?
			'screen' 	=> isset( $args['screen'] ) ? $args['screen'] : null
		) );
	}

	function ajax_user_can() {
		return current_user_can( 'manage_options' );
	}

    function column_default($item, $column_name){
        switch($column_name){
            case 'ID':
            case 'button_name':
            case 'price':
            case 'item_number':
            case 'shortcode':
                return $item[$column_name];
            default:
                //return print_r($item,true); //Show the whole array for troubleshooting purposes
        }
    }

    function column_button_name($item){
        $actions = array(
           'edit'      => sprintf('<a href="?page=%s&mode=%s&ppid=%s">Edit</a>','ppaddbutton','pppcodebtnedit',$item['ID']),
           'delete'    => sprintf('<a href="?page=%s&mode=%s&ppid=%s">Delete</a>',$_REQUEST['page'],'pppcodebtn_rem',$item['ID']),
        );
        return sprintf('%1$s %2$s',$item['button_name'],$this->row_actions($actions));
    }

    function get_columns(){
        $columns = array(
            'cb'        		=> '<input type="checkbox" />',
            'ID'     			=> 'ID',
           	'button_name'     	=> 'Button Name/Title',
            'price'    			=> 'Price',
            'item_number'    	=> 'Item Number',
            'shortcode'  		=> 'Shortcode',
        );
        return $columns;
    }
    
    function get_sortable_columns() {
        $sortable_columns = array(
            'ID'     			=> array('id',false),
            'button_name'     	=> array('button_name',false),
            'price'    			=> array('price',false),
            'item_number'		=> array('item_number',false),
            'shortcode'  		=> array('shortcode',false),
        );
        return $sortable_columns;
    }
    
    function column_cb($item){
        return sprintf('<input type="checkbox" name="%1$s[]" value="%2$s" />', $this->_args['singular'],$item['ID']);
    }
    
    function get_bulk_actions() {
        return array('delete'=> 'Delete');
    }
    
    function process_bulk_action() {
        if( 'delete' === $this->current_action() ) {
            //echo 'Items deleted (or they would be if we had items to delete)!';
        }
    }
    
    function prepare_items() {
        global $wpdb; 
		$tdata					= array();
		$data					= array();
        $per_page 				= 20;
        $columns 				= $this->get_columns();
        $hidden 				= array();
        $sortable 				= $this->get_sortable_columns();
        $this->_column_headers 	= array($columns, $hidden, $sortable);
        $table_name 			= $wpdb->prefix . "pppromoproducts";
		$pplist 				= $wpdb->get_results("SELECT pid,item_name,item_num ,special_instr ,amount,shipping,shipping_amt,return_url,cancel_url,currency_code,button_type,pp_emailadd FROM $table_name ORDER BY pid DESC");
		//echo '<pre>$output:'.print_r($pplist, true).'</pre>';
		if(!empty($pplist)){
			foreach ($pplist as $pplist2) {
				if(stripslashes($pplist2->item_num)==''){$pplist2->item_num = 'N/A';}
				$curcode = $pplist2->currency_code != '' ? $pplist2->currency_code : getMultiOption('ppp_options','currencyCode');
				$tdata[]	= array(
					'ID'			=> $pplist2->pid,
		            'button_name'  	=> stripslashes($pplist2->item_name),
		            'item_number'   => stripslashes($pplist2->item_num),
		            'price'			=> apply_filters('paypal-promo-price-symbol','$',$curcode).stripslashes($pplist2->amount),
		            'shortcode'  	=> '[paypalpromo id='.$pplist2->pid.']',
				);
			}
		}
        $data = $tdata;
       	$this->process_bulk_action();

        function usort_reorder($a,$b){
            $orderby = (!empty($_REQUEST['orderby'])) ? sanitize_text_field($_REQUEST['orderby']) : 'button_name'; //If no sort, default to title
            $order = (!empty($_REQUEST['order'])) ? sanitize_text_field($_REQUEST['order']) : 'asc'; //If no order, default to asc
 			$noorder = false;
			if(isset($a[$orderby]) && isset($b[$orderby])){
          		$result = strcmp($a[$orderby], $b[$orderby]); //Determine sort order
			}else{
				$result = $a;
				$noorder = true;
			}
			if(!$noorder)
           		return ( $order === 'asc' ) ? $result : -$result; //Send final sort direction to usort
			else
           		return $result; //Send final sort direction to usort
        }
		usort($data, 'usort_reorder');
        $current_page 	= $this->get_pagenum();
        $total_items 	= count($data);
        $data 			= array_slice($data,(($current_page-1)*$per_page),$per_page);
        $this->items 	= $data;
        $this->set_pagination_args( array(
            'total_items' => $total_items,                  //WE have to calculate the total number of items
            'per_page'    => $per_page,                     //WE have to determine how many items to show on a page
            'total_pages' => ceil($total_items/$per_page)   //WE have to calculate the total number of pages
        ) );
    }
}