<?php
if(!class_exists('WP_List_Table')){
    require_once( ABSPATH . 'wp-admin/includes/class-wp-list-table.php' );
}

class WP_PayPalPromos_List_Table extends WP_List_Table {

	function __construct( $args = array() ) {
		parent::__construct( array(
            'singular'  => 'promocode',     //singular name of the listed records
            'plural'    => 'promocodes',    //plural name of the listed records
            'ajax'      => true,       		//does this table support ajax?
			'screen' 	=> isset( $args['screen'] ) ? $args['screen'] : null
		) );
	}

	function ajax_user_can() {
		return current_user_can( 'manage_options' );
	}

    function column_default($item, $column_name){
        switch($column_name){
            case 'ID':
            case 'promo_code_name':
            case 'promo_code_discount':
            case 'used':
            case 'start_date':
            case 'expires':
            case 'assigned_buttons':
            case 'promo_code':
                return $item[$column_name];
            default:
                //return print_r($item,true); //Show the whole array for troubleshooting purposes
        }
    }

    function column_promo_code_name($item){
        $actions = array(
           'edit'      => sprintf('<a href="?page=%s&mode=%s&ppid=%s">Edit</a>','ppaddcode','pppcodeedit',$item['ID']),
           'delete'    => sprintf('<a href="?page=%s&mode=%s&ppid=%s " onClick="return confirm(\'Delete this PayPal PromoCode?\')">Delete</a>',$_REQUEST['page'],'pppcode_rem',$item['ID']),
        );
        return sprintf('%1$s %2$s',$item['promo_code_name'],$this->row_actions($actions));
    }

    function get_columns(){
        $columns = array(
            'cb' => '<input type="checkbox" />',
            'ID' => 'ID',
           	'promo_code_name' => 'Promo Code Name',
            'promo_code_discount' => 'Discount',
            'used' => '#Times Used',
            'start_date' => 'Start Date',
            'expires' => 'Expires',
            'assigned_buttons' => 'Assigned Buttons',
            'promo_code' => 'Promocode',
      );
        return $columns;
    }
    
    function get_sortable_columns() {
        $sortable_columns = array(
            'ID' => array('ID',false),
            'promo_code_name' => array('promo_code_name',false),
            'promo_code_discount' => array('promo_code_discount',false),
            'used' => array('used',false),
            'start_date' => array('start_date',false),
            'expires' => array('expires',false),
            'assigned_buttons' => array('assigned_buttons',false),
            'promo_code' => array('promo_code',false),
        );
        return $sortable_columns;
    }
    
    function column_cb($item){
        return sprintf('<input type="checkbox" name="%1$s[]" value="%2$s" />', $this->_args['singular'],$item['ID']);
    }
    
    function get_bulk_actions() {
        return array('delete'=> 'Delete');
    }
    
    function process_bulk_action() {
        if( 'delete' === $this->current_action() ) {
            //echo 'Items deleted (or they would be if we had items to delete)!';
        }
    }
    
    function prepare_items() {
        global $wpdb; 
        global $paypal_promocode_instance;
		$data					= array();
		$tdata					= array();
        $per_page 				= 20;
        $columns 				= $this->get_columns();
        $hidden 				= array();
        $sortable 				= $this->get_sortable_columns();
        $this->_column_headers 	= array($columns, $hidden, $sortable);
		$table_name 	= $wpdb->prefix . "pppromo";
		$pplist 		= $wpdb->get_results("SELECT * FROM $table_name ORDER BY ppid DESC");
		if(!empty($pplist)){
			foreach ($pplist as $pplist2) {
	 			$buttonsfor = unserialize($pplist2->description);
				$showbuttonsfor 	= array();
				foreach($buttonsfor as $buttonsis){
					$showbuttonsfor[]= $buttonsis;
				}
				$disctype1 = stripslashes($pplist2->ppdiscount);
				$disctype = $disctype1;
		 		if($pplist2->ppdiscounttype=='1'){ /* translator: Admin Listing of the Discount Type for Percent off price  */
					$disctype = sprintf( __("%s OFF Price", 'paypal-promo-plugin-locale'),$disctype1.'%');
				}elseif($pplist2->ppdiscounttype=='2') {  /* translator: Admin Listing of the Discount Type for Dollar Amount off price  */
					$disctype = sprintf( __("%s%s OFF Price", 'paypal-promo-plugin-locale'),apply_filters('paypal-promo-price-symbol','$'),$disctype1);
				}elseif($pplist2->ppdiscounttype=='3') {  /* translator: Admin Listing of the Discount Type for set price  */
					$disctype = sprintf( __("Final Price of %s%s", 'paypal-promo-plugin-locale'),apply_filters('paypal-promo-price-symbol','$'),$disctype1);
				}
				$tdata[]	= array(
					'ID'					=> $pplist2->ppid,
		            'promo_code_name'  		=> stripslashes($pplist2->ppname),
		            'promo_code_discount'	=> $disctype,
		            'used'					=> /*translator: referring to the number of 'times' a promo code was used.*/ $paypal_promocode_instance->get_pppcounts('ppp_btntrk_'.stripslashes($pplist2->ppname)).__(' times', 'paypal-promo-plugin-locale'),
		            'start_date'  			=> date_format(date_create($pplist2->sdate),'m\/d\/Y'),
		            'expires'  				=> date_format(date_create($pplist2->edate),'m\/d\/Y'),
		            'assigned_buttons' 	 	=> implode(', ',$showbuttonsfor),
		            'promo_code'  			=> stripslashes($pplist2->ppname),
				);
			}
		}
        $data 					= $tdata;
       	$this->process_bulk_action();

        function pppr_usort_reorder_codes($a,$b){
            $orderby = (!empty($_REQUEST['orderby'])) ? sanitize_text_field($_REQUEST['orderby']) : 'promo_code_name'; //If no sort, default to title
            $order = (!empty($_REQUEST['order'])) ? sanitize_text_field($_REQUEST['order']) : 'asc'; //If no order, default to asc
 			$noorder = false;
			if(isset($a[$orderby]) && isset($b[$orderby])){
          		$result = strcmp($a[$orderby], $b[$orderby]); //Determine sort order
			}else{
				$result = $a;
				$noorder = true;
			}
			if(!$noorder)
           		return ( $order === 'asc' ) ? $result : -$result; //Send final sort direction to usort
			else
           		return $result; //Send final sort direction to usort
				
        }
        usort($data, 'pppr_usort_reorder_codes');
        $current_page 	= $this->get_pagenum();
        $total_items 	= count($data);
        $data 			= array_slice($data,(($current_page-1)*$per_page),$per_page);
        $this->items 	= $data;
        $this->set_pagination_args( array(
            'total_items' => $total_items,                  //WE have to calculate the total number of items
            'per_page'    => $per_page,                     //WE have to determine how many items to show on a page
            'total_pages' => ceil($total_items/$per_page)   //WE have to calculate the total number of pages
        ) );
    }
}